summaryrefslogtreecommitdiffstats
path: root/kicker/kicker/ui/k_mnu.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kicker/kicker/ui/k_mnu.cpp
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kicker/kicker/ui/k_mnu.cpp')
-rw-r--r--kicker/kicker/ui/k_mnu.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index 0506201f5..2b0afad5f 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -94,7 +94,7 @@ PanelKMenu::PanelKMenu()
"slotServiceStartedByStorageId(TQString,TQString)",
false);
displayRepairTimer = new TQTimer( this );
- connect( displayRepairTimer, SIGNAL(timeout()), this, SLOT(repairDisplay()) );
+ connect( displayRepairTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(repairDisplay()) );
}
PanelKMenu::~PanelKMenu()
@@ -125,7 +125,7 @@ void PanelKMenu::hideMenu()
while (isShown() == true)
kapp->eventLoop()->processEvents(1000);
TQTimer *windowtimer = new TQTimer( this );
- connect( windowtimer, SIGNAL(timeout()), this, SLOT(windowClearTimeout()) );
+ connect( windowtimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(windowClearTimeout()) );
windowTimerTimedOut = false;
windowtimer->start( 0, TRUE ); // Wait for all window system events to be processed
while (windowTimerTimedOut == false)
@@ -138,7 +138,7 @@ void PanelKMenu::hideMenu()
// thereby removing a bad shutdown screen artifact while still providing
// a somewhat snappy user interface.
TQTimer *delaytimer = new TQTimer( this );
- connect( delaytimer, SIGNAL(timeout()), this, SLOT(windowClearTimeout()) );
+ connect( delaytimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(windowClearTimeout()) );
windowTimerTimedOut = false;
delaytimer->start( 100, TRUE ); // Wait for 100 milliseconds
while (windowTimerTimedOut == false)
@@ -207,7 +207,7 @@ void PanelKMenu::paletteChanged()
if (!loadSidePixmap())
{
sidePixmap = sideTilePixmap = TQPixmap();
- setMinimumSize( sizeHint() );
+ setMinimumSize( tqsizeHint() );
}
}
@@ -415,10 +415,10 @@ void PanelKMenu::repairDisplay(void) {
displayRepairTimer->stop();
// Now do a nasty hack to prevent search bar merging into the side image
- // This forces a layout/repaint of the qpopupmenu
- repaint(); // This ensures that the side bar image was applied
+ // This forces a tqlayout/tqrepaint of the qpopupmenu
+ tqrepaint(); // This ensures that the side bar image was applied
styleChange(style()); // This forces a call to the private function updateSize(TRUE) inside the qpopupmenu.
- update(); // This repaints the entire popup menu to apply the widget size/alignment changes made above
+ update(); // This tqrepaints the entire popup menu to apply the widget size/tqalignment changes made above
}
}
@@ -579,32 +579,32 @@ void PanelKMenu::showMenu()
TQRect PanelKMenu::sideImageRect()
{
- return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
+ return TQStyle::tqvisualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
void PanelKMenu::resizeEvent(TQResizeEvent * e)
{
// kdDebug(1210) << "PanelKMenu::resizeEvent():" << endl;
-// kdDebug(1210) << geometry().width() << ", " << geometry().height() << endl;
+// kdDebug(1210) << tqgeometry().width() << ", " << tqgeometry().height() << endl;
PanelServiceMenu::resizeEvent(e);
- setFrameRect( TQStyle::visualRect( TQRect( sidePixmap.width(), 0,
+ setFrameRect( TQStyle::tqvisualRect( TQRect( sidePixmap.width(), 0,
width() - sidePixmap.width(), height() ), this ) );
}
//Workaround Qt3.3.x sizing bug, by ensuring we're always wide enough.
void PanelKMenu::resize(int width, int height)
{
- width = kMax(width, maximumSize().width());
+ width = kMax(width, tqmaximumSize().width());
PanelServiceMenu::resize(width, height);
}
-TQSize PanelKMenu::sizeHint() const
+TQSize PanelKMenu::tqsizeHint() const
{
- TQSize s = PanelServiceMenu::sizeHint();
-// kdDebug(1210) << "PanelKMenu::sizeHint()" << endl;
+ TQSize s = PanelServiceMenu::tqsizeHint();
+// kdDebug(1210) << "PanelKMenu::tqsizeHint()" << endl;
// kdDebug(1210) << s.width() << ", " << s.height() << endl;
return s;
}
@@ -621,7 +621,7 @@ void PanelKMenu::paintEvent(TQPaintEvent * e)
style().drawPrimitive( TQStyle::PE_PanelPopup, &p,
TQRect( 0, 0, width(), height() ),
- colorGroup(), TQStyle::Style_Default,
+ tqcolorGroup(), TQStyle::Style_Default,
TQStyleOption( frameWidth(), 0 ) );
TQRect r = sideImageRect();
@@ -648,7 +648,7 @@ TQMouseEvent PanelKMenu::translateMouseEvent( TQMouseEvent* e )
{
TQRect side = sideImageRect();
- if ( !side.contains( e->pos() ) )
+ if ( !side.tqcontains( e->pos() ) )
return *e;
TQPoint newpos( e->pos() );
@@ -700,7 +700,7 @@ void PanelKMenu::keyPressEvent(TQKeyEvent* e)
// user presses '/'. This is the same shortcut as
// konqueror is using, and afaik it's hardcoded both
// here and there. This sucks badly for many non-us
- // keyboard layouts, but for the sake of consistency
+ // keyboard tqlayouts, but for the sake of consistency
// we follow konqueror.
if (!searchEdit) return KPanelMenu::keyPressEvent(e);